==> dotclear-1.2.zip: dotclear/l10n/fr/install.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Installation'] = 'Installation';
$GLOBALS['__l10n']['Welcome on DotClear installation'] = 'Bienvenue sur l\'installeur de DotClear';
$GLOBALS['__l10n']['You are about to install DotClear. Please choose your language and encoding.'] = 'Vous allez installer DotClear. Choisissez votre langue et l\'encodage.';
$GLOBALS['__l10n']['Go'] = 'Continuer';
$GLOBALS['__l10n']['Next step'] = 'tape suivante';
$GLOBALS['__l10n']['DotClear is still installed.'] = 'DotClear est dj install.';
$GLOBALS['__l10n']['Upgrade'] = 'Mettre  jour';
$GLOBALS['__l10n']['Note: You must accept session cookies to use this installer.'] = 'Note : Vous devez accepter les cookies de session pour utiliser cet installeur';
$GLOBALS['__l10n']['Checking your configuration'] = 'Vrification de votre configuration';
$GLOBALS['__l10n']['PHP version and modules'] = 'Version de PHP et modules';
$GLOBALS['__l10n']['PHP version is %s.'] = 'La version de PHP est %s';
$GLOBALS['__l10n']['PHP version is %s. Version 4.1 or better is required.'] = 'La version de PHP est %s. La version 4.1 ou plus est ncessaire.';
$GLOBALS['__l10n']['%s module is present.'] = 'Le module %s est prsent.';
$GLOBALS['__l10n']['%s module is not present.'] = 'Le module %s est absent.';
$GLOBALS['__l10n']['Files permissions'] = 'Permissions sur les fichiers';
$GLOBALS['__l10n']['%s is writable.'] = '%s est accessible en criture.';
$GLOBALS['__l10n']['%s is not writable. Please change its permissions to install.'] = '%s n\'est pas accessible en criture. Changez ses permission pour installer.';
$GLOBALS['__l10n']['DotClear cannot be installed.'] = 'DotClear ne peut pas tre install.';
$GLOBALS['__l10n']['Your PHP configuration is not valid. Please contact your Web host to solve this problem.'] = 'Votre configuration n\'est pas suffisante. Contactez votre hbergeur pour rsoudre ce problme.';
$GLOBALS['__l10n']['Some files or directories are not writable. Please change their permissions to install DotClear.'] = 'Des fichiers ou rpertoires ne sont pas accessibles en critures. Changez leurs permissions pour installer DotClear.';
$GLOBALS['__l10n']['DotClear can be installed on your site.'] = 'DotClear peut tre install sur votre site.';
$GLOBALS['__l10n']['Database parameters'] = 'Paramtres de la base de donnes';
$GLOBALS['__l10n']['Invalid tables prefix. It can contain only letters or "_".'] = 'Prfixe des tables invalide. Il ne peut contenir que des lettre ou "_".';
$GLOBALS['__l10n']['Error, check your parameters.'] = 'Erreur, vrifiez vos paramtres.';
$GLOBALS['__l10n']['Server address'] = 'Adresse du serveur';
$GLOBALS['__l10n']['User ID'] = 'Nom d\'utilisateur';
$GLOBALS['__l10n']['Password'] = 'Mot de passe';
$GLOBALS['__l10n']['Database name'] = 'Nom de la base';
$GLOBALS['__l10n']['Tables prefix'] = 'Prfixe des tables';
$GLOBALS['__l10n']['Create tables'] = 'Crer les tables';
$GLOBALS['__l10n']['DotClear seems to be present on your site. You may want to upgrade.'] = 'DotClear semble tre prsent sur votre site. Vous souhaitez sans doute le mettre  jour.';
$GLOBALS['__l10n']['Don\'t forget to upload your old dotclear.ini in conf/ directory before upgrade.'] = 'N\'oubliez pas de dposer votre ancien fichier dotclear.ini dans le rpertoire conf/ avant de mettre  jour.';
$GLOBALS['__l10n']['Tables creation'] = 'Cration des tables';
$GLOBALS['__l10n']['Table %s exists'] = 'La table %s existe';
$GLOBALS['__l10n']['Field %s exists'] = 'Le champ %s existe';
$GLOBALS['__l10n']['Create table %s'] = 'Cration de la table %s';
$GLOBALS['__l10n']['Add fulltext key %s'] = 'Ajout de la cl fulltext %s';
$GLOBALS['__l10n']['Creation of first category'] = 'Cration de la premire catgorie';
$GLOBALS['__l10n']['Unable to create all tables. Please check if the tables don\'t exist yet.'] = 'Impossible de crer toutes les tables. Vrifiez qu\'elles n\'existent pas dj.';
$GLOBALS['__l10n']['Tables successfully created.'] = 'Tables cres avec succs.';
$GLOBALS['__l10n']['DotClear will run properly even if warnings are issued.'] = 'DotClear fonctionnera normalement mme si des avertissements sont affichs.';
$GLOBALS['__l10n']['Creation of first user'] = 'Cration du premier utilisateur';
$GLOBALS['__l10n']['You are about to create the first user of your blog. This user will be administrator.'] = 'Vous allez crer le premier utilisateur de votre blogue. Cet utilisateur sera administrateur.';
$GLOBALS['__l10n']['Create user'] = 'Crer l\'utilisateur';
$GLOBALS['__l10n']['User succesfuly created'] = 'Utilisateur cr avec succs';
$GLOBALS['__l10n']['Blog configuration'] = 'Configuration du weblogue';
$GLOBALS['__l10n']['DotClear needs to know in which directory it has been installed. For example, if DotClear has been installed in %s/dotclear, then please type "/dotclear" in the field below:'] = 'Il est ncessaire d\'indiquer  DotClear dans quel rpertoire il a t install. Par exemple, si DotClear est install dans %s/dotclear, veuillez indiquer "/dotclear" dans le champs ci-dessous :';
$GLOBALS['__l10n']['DotClear location'] = 'Emplacement de DotClear';
$GLOBALS['__l10n']['Your blog\'s name'] = 'Nom de votre weblogue';
$GLOBALS['__l10n']['My first weblog'] = 'Mon premier weblogue';
$GLOBALS['__l10n']['Your blog archive addresses (permalinks) may be displayed in various formats. The "Query string" URLs will be displayed as "index.php?/2002/04". The "Path info" URLs will be displayed as "index.php/2002/04" (preferred method for search engine optimization). And the "Get" URLs will be displayed as "index.php?d=2002/04" (only for mod_rewrite fans).'] = 'Les adresses de vos archives (liens permanents) peuvent tre affiches dans diffrents formats. Les URLs au format "Query string" seront affiches comme "index.php?/2002/04". Les URLs au format "Path info" seront affiches comme "index.php/2002/04" (mthode conseille pour une meilleure indexation). Les URLs au format "Get" seront affiches comme "index.php?d=2002/04" (seulement pour les amateurs de mod_rewrite).';
$GLOBALS['__l10n']['Please note that "Path info" type could be broken on some Web hosting configurations.'] = 'Notez que le format "Path info" peut ne pas fonctionne sur tous les hbergements.';
$GLOBALS['__l10n']['URLs format'] = 'Format des URLs';
$GLOBALS['__l10n']['Save'] = 'Enregistrer';
$GLOBALS['__l10n']['Unable to write dotclear.ini'] = 'Impossible d\'crire dotclear.ini';
$GLOBALS['__l10n']['Weblog succesfully configured'] = 'Weblogue configur avec succs';
$GLOBALS['__l10n']['End installation'] = 'Terminer l\'installation';
$GLOBALS['__l10n']['End of installation'] = 'Fin de l\'installation';
$GLOBALS['__l10n']['First post'] = 'Premier billet';
$GLOBALS['__l10n']['This is the first post. Please edit it.'] = 'Ceci est le premier billet. ditez le.';
$GLOBALS['__l10n']['Creation of first entry.'] = 'Cration du premier billet.';
$GLOBALS['__l10n']['Creation of first entry failed.'] = 'La cration du premier billet a chou.';
$GLOBALS['__l10n']['Creation of config file.'] = 'Cration du fichier de configuration.';
$GLOBALS['__l10n']['Creation of config file failed.'] = 'La cration du fichier de configuration a chou.';
$GLOBALS['__l10n']['An error occured while finishing installation.'] = 'Une erreur s\'est produite en terminant l\'installation.';
$GLOBALS['__l10n']['Congratulations!'] = 'Flicitations !';
$GLOBALS['__l10n']['You successfully installed DotClear. Have fun.'] = 'Vous avez install DotClear avec succs. Amusez vous bien.';
$GLOBALS['__l10n']['Manage your blog'] = 'Administrer votre weblogue';
$GLOBALS['__l10n']['Upgrade DotClear'] = 'Mise  jour de DotClear';
$GLOBALS['__l10n']['Update URLed titles'] = 'Mise  jour des titres URLiss';
$GLOBALS['__l10n']['Update %s'] = 'Mise  jour de %s';
$GLOBALS['__l10n']['Reord categories'] = 'Rordonnancement des catgories';
$GLOBALS['__l10n']['Reord categories failed'] = 'Rordonnancement des catgories chou';
$GLOBALS['__l10n']['Update of dotclear.ini'] = 'Mise  jour de dotclear.ini';
$GLOBALS['__l10n']['Update of dotclear.ini failed'] = 'Mise  jour de dotclear.ini choue';
$GLOBALS['__l10n']['DotClear successfully upgraded.'] = 'DotClear mis  jour avec succs.';
$GLOBALS['__l10n']['Log in'] = 'Connexion';
?>

==> dotclear-1.2.1.zip: dotclear/l10n/fr/install.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Installation'] = 'Installation';
$GLOBALS['__l10n']['Welcome on DotClear installation'] = 'Bienvenue sur l\'installeur de DotClear';
$GLOBALS['__l10n']['You are about to install DotClear. Please choose your language and encoding.'] = 'Vous allez installer DotClear. Choisissez votre langue et l\'encodage.';
$GLOBALS['__l10n']['Go'] = 'Continuer';
$GLOBALS['__l10n']['Next step'] = 'tape suivante';
$GLOBALS['__l10n']['DotClear is still installed.'] = 'DotClear est dj install.';
$GLOBALS['__l10n']['Upgrade'] = 'Mettre  jour';
$GLOBALS['__l10n']['Note: You must accept session cookies to use this installer.'] = 'Note : Vous devez accepter les cookies de session pour utiliser cet installeur';
$GLOBALS['__l10n']['Checking your configuration'] = 'Vrification de votre configuration';
$GLOBALS['__l10n']['PHP version and modules'] = 'Version de PHP et modules';
$GLOBALS['__l10n']['PHP version is %s.'] = 'La version de PHP est %s';
$GLOBALS['__l10n']['PHP version is %s. Version 4.1 or better is required.'] = 'La version de PHP est %s. La version 4.1 ou plus est ncessaire.';
$GLOBALS['__l10n']['%s module is present.'] = 'Le module %s est prsent.';
$GLOBALS['__l10n']['%s module is not present.'] = 'Le module %s est absent.';
$GLOBALS['__l10n']['Files permissions'] = 'Permissions sur les fichiers';
$GLOBALS['__l10n']['%s is writable.'] = '%s est accessible en criture.';
$GLOBALS['__l10n']['%s is not writable. Please change its permissions to install.'] = '%s n\'est pas accessible en criture. Changez ses permission pour installer.';
$GLOBALS['__l10n']['DotClear cannot be installed.'] = 'DotClear ne peut pas tre install.';
$GLOBALS['__l10n']['Your PHP configuration is not valid. Please contact your Web host to solve this problem.'] = 'Votre configuration n\'est pas suffisante. Contactez votre hbergeur pour rsoudre ce problme.';
$GLOBALS['__l10n']['Some files or directories are not writable. Please change their permissions to install DotClear.'] = 'Des fichiers ou rpertoires ne sont pas accessibles en critures. Changez leurs permissions pour installer DotClear.';
$GLOBALS['__l10n']['DotClear can be installed on your site.'] = 'DotClear peut tre install sur votre site.';
$GLOBALS['__l10n']['Database parameters'] = 'Paramtres de la base de donnes';
$GLOBALS['__l10n']['Invalid tables prefix. It can contain only letters or "_".'] = 'Prfixe des tables invalide. Il ne peut contenir que des lettre ou "_".';
$GLOBALS['__l10n']['Error, check your parameters.'] = 'Erreur, vrifiez vos paramtres.';
$GLOBALS['__l10n']['Server address'] = 'Adresse du serveur';
$GLOBALS['__l10n']['User ID'] = 'Nom d\'utilisateur';
$GLOBALS['__l10n']['Password'] = 'Mot de passe';
$GLOBALS['__l10n']['Database name'] = 'Nom de la base';
$GLOBALS['__l10n']['Tables prefix'] = 'Prfixe des tables';
$GLOBALS['__l10n']['Create tables'] = 'Crer les tables';
$GLOBALS['__l10n']['DotClear seems to be present on your site. You may want to upgrade.'] = 'DotClear semble tre prsent sur votre site. Vous souhaitez sans doute le mettre  jour.';
$GLOBALS['__l10n']['Don\'t forget to upload your old dotclear.ini in conf/ directory before upgrade.'] = 'N\'oubliez pas de dposer votre ancien fichier dotclear.ini dans le rpertoire conf/ avant de mettre  jour.';
$GLOBALS['__l10n']['Tables creation'] = 'Cration des tables';
$GLOBALS['__l10n']['Table %s exists'] = 'La table %s existe';
$GLOBALS['__l10n']['Field %s exists'] = 'Le champ %s existe';
$GLOBALS['__l10n']['Create table %s'] = 'Cration de la table %s';
$GLOBALS['__l10n']['Add fulltext key %s'] = 'Ajout de la cl fulltext %s';
$GLOBALS['__l10n']['Creation of first category'] = 'Cration de la premire catgorie';
$GLOBALS['__l10n']['Unable to create all tables. Please check if the tables don\'t exist yet.'] = 'Impossible de crer toutes les tables. Vrifiez qu\'elles n\'existent pas dj.';
$GLOBALS['__l10n']['Tables successfully created.'] = 'Tables cres avec succs.';
$GLOBALS['__l10n']['DotClear will run properly even if warnings are issued.'] = 'DotClear fonctionnera normalement mme si des avertissements sont affichs.';
$GLOBALS['__l10n']['Creation of first user'] = 'Cration du premier utilisateur';
$GLOBALS['__l10n']['You are about to create the first user of your blog. This user will be administrator.'] = 'Vous allez crer le premier utilisateur de votre blogue. Cet utilisateur sera administrateur.';
$GLOBALS['__l10n']['Create user'] = 'Crer l\'utilisateur';
$GLOBALS['__l10n']['User successfully created'] = 'Utilisateur cr avec succs';
$GLOBALS['__l10n']['Blog configuration'] = 'Configuration du weblogue';
$GLOBALS['__l10n']['DotClear needs to know in which directory it has been installed. For example, if DotClear has been installed in %s/dotclear, then please type "/dotclear" in the field below:'] = 'Il est ncessaire d\'indiquer  DotClear dans quel rpertoire il a t install. Par exemple, si DotClear est install dans %s/dotclear, veuillez indiquer "/dotclear" dans le champs ci-dessous :';
$GLOBALS['__l10n']['DotClear location'] = 'Emplacement de DotClear';
$GLOBALS['__l10n']['Your blog\'s name'] = 'Nom de votre weblogue';
$GLOBALS['__l10n']['My first weblog'] = 'Mon premier weblogue';
$GLOBALS['__l10n']['Your blog archive addresses (permalinks) may be displayed in various formats. The "Query string" URLs will be displayed as "index.php?/2002/04". The "Path info" URLs will be displayed as "index.php/2002/04" (preferred method for search engine optimization). And the "Get" URLs will be displayed as "index.php?d=2002/04" (only for mod_rewrite fans).'] = 'Les adresses de vos archives (liens permanents) peuvent tre affiches dans diffrents formats. Les URLs au format "Query string" seront affiches comme "index.php?/2002/04". Les URLs au format "Path info" seront affiches comme "index.php/2002/04" (mthode conseille pour une meilleure indexation). Les URLs au format "Get" seront affiches comme "index.php?d=2002/04" (seulement pour les amateurs de mod_rewrite).';
$GLOBALS['__l10n']['Please note that "Path info" type could be broken on some Web hosting configurations.'] = 'Notez que le format "Path info" peut ne pas fonctionne sur tous les hbergements.';
$GLOBALS['__l10n']['URLs format'] = 'Format des URLs';
$GLOBALS['__l10n']['Save'] = 'Enregistrer';
$GLOBALS['__l10n']['Unable to write dotclear.ini'] = 'Impossible d\'crire dotclear.ini';
$GLOBALS['__l10n']['Weblog successfully configured'] = 'Weblogue configur avec succs';
$GLOBALS['__l10n']['End installation'] = 'Terminer l\'installation';
$GLOBALS['__l10n']['End of installation'] = 'Fin de l\'installation';
$GLOBALS['__l10n']['First post'] = 'Premier billet';
$GLOBALS['__l10n']['This is the first post. Please edit it.'] = 'Ceci est le premier billet. ditez le.';
$GLOBALS['__l10n']['Creation of first entry.'] = 'Cration du premier billet.';
$GLOBALS['__l10n']['Creation of first entry failed.'] = 'La cration du premier billet a chou.';
$GLOBALS['__l10n']['Creation of config file.'] = 'Cration du fichier de configuration.';
$GLOBALS['__l10n']['Creation of config file failed.'] = 'La cration du fichier de configuration a chou.';
$GLOBALS['__l10n']['An error occured while finishing installation.'] = 'Une erreur s\'est produite en terminant l\'installation.';
$GLOBALS['__l10n']['Congratulations!'] = 'Flicitations !';
$GLOBALS['__l10n']['You successfully installed DotClear. Have fun.'] = 'Vous avez install DotClear avec succs. Amusez vous bien.';
$GLOBALS['__l10n']['Manage your blog'] = 'Administrer votre weblogue';
$GLOBALS['__l10n']['Upgrade DotClear'] = 'Mise  jour de DotClear';
$GLOBALS['__l10n']['Update URLed titles'] = 'Mise  jour des titres URLiss';
$GLOBALS['__l10n']['Update %s'] = 'Mise  jour de %s';
$GLOBALS['__l10n']['Reord categories'] = 'Rordonnancement des catgories';
$GLOBALS['__l10n']['Reord categories failed'] = 'Rordonnancement des catgories chou';
$GLOBALS['__l10n']['Update of dotclear.ini'] = 'Mise  jour de dotclear.ini';
$GLOBALS['__l10n']['Update of dotclear.ini failed'] = 'Mise  jour de dotclear.ini choue';
$GLOBALS['__l10n']['DotClear successfully upgraded.'] = 'DotClear mis  jour avec succs.';
$GLOBALS['__l10n']['Log in'] = 'Connexion';
?>
